@@ -9,6 +9,6 @@ from .chains.base import Chain  # noqa
 from .embeddings import visualize_embeddings  # noqa
 from .llms.base import BaseLLM  # noqa
 from .prompts.few_shot import FewShotPromptTemplate  # noqa
-from .prompts.prompt import PromptTemplate  # noqa
+from .prompts.prompt import new_format  # noqa
 
 visualize = ice_visualize
